
//*****************************************************************
//
// File Name	: 'uart.h'
// Title			: UART driver with buffer support
// Author		: Pascal Stang - Copyright (C) 2000-2002
// Created		: 11/22/2000
// Revised		: 11/01/2001
// Version		: 1.3
// Target MCU	: ATMEL AVR Series
// Editor Tabs	: 3
//
// This code is distributed under the GNU Public License
//		which can be found at http://www.gnu.org/licenses/gpl.txt
//
//*****************************************************************

#ifndef UART_H
#define UART_H

#include "global.h"
#include "buffer.h"

// default baud rate
// can be changed by uartSetBaudRate()
#define UART_BAUD_RATE         38400

// address space defines
// internal ram
//#ifndef INT_RAM_BASE
// define if needed
#define INT_RAM_BASE					0x0060
// location of uart transmit buffer
#define UART_TX_BUFFER_ADDR		0x01C0
#define UART_TX_BUFFER_SIZE		0x0020
// location of uart receive buffer
#define UART_RX_BUFFER_ADDR		0x01E0
#define UART_RX_BUFFER_SIZE		0x0020

#define INT_RAM_END					0x0260
//#endif

// functions

// initializes transmit and receive buffers
// called from uartInit()
void uartInitBuffers(void);

// initializes uart
void uartInit(void);

// set the uart baud rate
void uartSetBaudRate(u16 baudrate);

// returns pointer to the receive buffer structure
cBuffer* uartGetRxBuffer(void);

// returns pointer to the transmit buffer structure
cBuffer* uartGetTxBuffer(void);

// sends a single byte over the uart
void uartSendByte(u08 data);

// gets a single byte from the uart receive buffer
// function returns TRUE if data was available, FALSE if not
// actual data is returned in variable pointed to by "data"
// example usage:
// char myReceivedByte;
// uartReceiveByte( &myReceivedByte );
u08 uartReceiveByte(u08* data);

// returns TRUE/FALSE if receive buffer is empty/not-empty
u08 uartReceiveBufferIsEmpty(void);

// flushes (deletes) all data from receive buffer
void uartFlushReceiveBuffer(void);

// begins transmission of the transmit buffer under interrupt control
void uartSendTxBuffer(void);

// sends a buffer of length nBytes via the uart using interrupt control
u08  uartSendBuffer(char *buffer, u16 nBytes);

#endif

